<template>
  <div>
    <list-condition-template ref="table" :form="listQuery" :formLabel="formLabel"
                             :tableData="tableData" :total="total"
                             @page-info-change="handlePageInfoChange">
      <template slot="otherElement">
        <el-form-item>
          <el-button size="mini" type="primary" @click="queryData">查询</el-button>
          <el-button size="mini" @click="resetQuery">重置</el-button>
        </el-form-item>
      </template>
      <template slot="columns">
        <el-table-column label="内容描述" prop="contentDesc" show-overflow-tooltip>
          <template slot-scope="scope">
            <span v-html="scope.row.contentDesc"></span>
          </template>
        </el-table-column>
        <el-table-column label="用户昵称" prop="optUserName">
        </el-table-column>
        <el-table-column label="反馈时间" prop="optTime"></el-table-column>
        <el-table-column label="回复状态" prop="replyFlag">
          <template slot-scope="scope">
            <span
                  :style="{ color: scope.row.replyFlag === '1' ? '#10b434' :'#d0261e'}">{{scope.row.replyFlag === '1' ? '已回复' : '未回复'}}</span>
          </template>
        </el-table-column>
        <el-table-column label="操作" :width="`${2 * $store.getters.colSize}px`">
          <template slot-scope="scope">
            <wly-btn @click="lookInfo(scope.row)">详情</wly-btn>
            <wly-btn :type="'warning'" v-show="scope.row.replyFlag === '0'"
                       @click="replay(scope.row)">回复</wly-btn>

          </template>
        </el-table-column>
      </template>
    </list-condition-template>
    <el-dialog :visible.sync="dialogVisible" title="反馈详情" :close-on-click-modal="false"
               :modal-append-to-body="false" width="40%">
      <user-suggest-info :form="form"></user-suggest-info>
      <div slot="footer" class="dialog-footer">
        <el-button size="mini" @click="dialogVisible=false">关闭</el-button>
      </div>
    </el-dialog>
  </div>
</template>
<script>
import userSuggestApi from '@/api/userSuggest'
import userSuggestInfo from '@/views/userSuggest/components/detailsInfo.vue'
export default {
  components: { userSuggestInfo },
  data () {
    return {
      listQuery: {
        replyFlag: null,
        evalStarTime: null,
        feedbackCategoryId: null
      },
      formLabel: [
        {
          model: 'evalStarTime',
          label: '反馈时间',
          type: 'date',
          valueFormat: 'yyyy-MM-dd'
        },
        {
          model: 'replyFlag',
          label: '回复状态',
          type: 'select',
          opts: [
            {
              id: '1',
              name: '已回复'
            },
            {
              id: '0',
              name: '未回复'
            }
          ]
        }],
      tableData: [],
      total: 0,
      dialogVisible: false,
      form: {},
      feedbackCategoryArray: [
        {
          id: '1',
          name: '建议反馈'
        },
        {
          id: '2',
          name: '问题投诉'
        }
      ]
    }
  },
  /**
   * 数据变化后刷新列表
   */
  activated () {
    this.queryList(this.$refs.table.getPageInfo())
  },
  methods: {
    /**
       * '分页信息改变时查询列表
       */
    handlePageInfoChange (pageInfo) {
      this.queryList(pageInfo)
    },

    /**
     * 重置
     */
    resetQuery () {
      this.$refs.table.reloadCurrent()
    },
    /**
     * 点击查询按钮
     */
    queryData () {
      this.$refs.table.changeCondition()
    },
    /**
         * 跳到回复页面
         */
    replay (row) {
      this.$router.push({
        name: 'userSuggestInfo',
        query: {
          id: row.id
        }
      })
    },
    /**
     * 查看详情
     */
    lookInfo (row) {
      userSuggestApi.detailsInfo({ id: row.id }).then(res => {
        if (res.data) {
          this.form = res.data
          this.dialogVisible = true
        }
      })
    },

    /**
         * 查询列表
         */
    queryList (pageInfo = { pageNum: 1, pageSize: 10 }) {
      this.listQuery.evalEndTime = this.listQuery.evalStarTime
      userSuggestApi.getList({ ...this.listQuery, ...pageInfo }).then((res) => {
        if (res.data) {
          this.tableData = res.data.list
          this.total = res.data.total
        }
      })
    }
  }
}
</script>
